@@ -42,8 +42,10 @@ from .cad_objects import (
     Edges,
     Vertices,
     show,
+    show_object,
     web_color,
     get_pick,
+    plugins,
 )
 
 from .defaults import (
@@ -59,9 +61,13 @@ from .tools import auto_show
 
 
 def versions():
-    print("jupyter_cadquery ", jcq_version)
-    print("cad_viewer_widget", cvw_version)
-    print("open cascade     ", occt_version())
+    print()
+    print("Versions:")
+    print("- jupyter_cadquery ", jcq_version)
+    print("- cad_viewer_widget", cvw_version)
+    print("- open cascade     ", occt_version())
+    print()
+    plugins()
 
 
 def open_viewer(viewer=None, default=True, **kwargs):
