@@ -14,13 +14,6 @@
 # limitations under the License.
 #
 
-try:
-    from cadquery_massembly import MAssembly, Mate
-
-    HAS_MASSEMBLY = True
-except ImportError:
-    HAS_MASSEMBLY = False
-
 try:
     import build123d as bd
 
@@ -29,6 +22,24 @@ try:
 except ImportError:
     HAS_BUILD123D = False
 
+try:
+    import alg123d as ad
+
+    HAS_ALG123D = True
+
+except ImportError:
+    HAS_ALG123D = False
+
+try:
+    from cadquery_massembly import MAssembly, Mate
+    from cadquery_massembly.massembly import MateDef
+
+    HAS_MASSEMBLY = True
+
+except ImportError:
+    HAS_MASSEMBLY = False
+
+
 from cadquery import (
     Workplane,
     Sketch,
@@ -44,11 +55,21 @@ from cadquery import (
     Assembly as CqAssembly,
     Color as CqColor,
 )
+from pyparsing import col
 
 from jupyter_cadquery.base import _PartGroup, _Part, _Edges, _Faces, _Vertices, _show
 
-from .utils import Color, flatten, warn
-from .ocp_utils import get_rgba, is_compound, is_shape, get_solids, get_faces, get_wires, get_edges, get_vertices
+from .utils import Color, get_color, flatten, warn
+from .ocp_utils import (
+    get_rgba,
+    is_compound,
+    is_shape,
+    get_solids,
+    get_faces,
+    get_wires,
+    get_edges,
+    get_vertices,
+)
 from .defaults import get_default, preset
 
 
@@ -57,6 +78,19 @@ THICK_EDGE_COLOR = "MediumOrchid"
 VERTEX_COLOR = "MediumOrchid"
 FACE_COLOR = "Violet"
 
+OBJECTS = {"objs": [], "names": [], "colors": [], "alphas": []}
+
+
+def plugins():
+    if HAS_BUILD123D or HAS_ALG123D or HAS_MASSEMBLY:
+        print("Plugins loaded:")
+        if HAS_BUILD123D:
+            print("- build123d")
+        if HAS_ALG123D:
+            print("- alg123d")
+        if HAS_MASSEMBLY:
+            print("- cadquery-massembly")
+
 
 def web_color(name):
     wc = Color(name)
@@ -69,10 +103,40 @@ def cq_wrap(obj):
     return w
 
 
+def convert_alg123d_massembly(obj, copy_mates=True):
+    if isinstance(obj, ad.MAssembly):
+        bma = obj
+        ma = MAssembly(
+            obj=None if bma.obj is None else Shape.cast(bma.obj.wrapped),
+            name=bma.cq_name,
+            color=None if bma.color is None else CqColor(*bma.color.to_tuple(percentage=True)),
+            loc=None if bma.loc is None else Location(bma.loc.wrapped),
+        )
+
+        for child in bma.children:
+            ma.add(convert_alg123d_massembly(child, False), name=child.name)
+
+        if copy_mates:
+            for name, mate_def in bma.mates.items():
+                assy_path = mate_def.assembly.split("/")
+                root = assy_path[1]
+                assy_path = assy_path[2:]
+                assy_name = "/".join(assy_path) if assy_path else root
+                ma.mates[name] = MateDef(
+                    convert_alg123d_massembly(mate_def.mate),
+                    ma.objects[assy_name],
+                    mate_def.origin,
+                )
+
+        return ma
+    else:
+        if isinstance(obj, ad.Mate):
+            return Mate(obj.origin.to_tuple(), obj.x_dir.to_tuple(), obj.z_dir.to_tuple())
+
+
 class Part(_Part):
     def __init__(self, shape, name="Part", color=None, show_faces=True, show_edges=True):
-        if color is None:
-            color = get_default("default_color")
+
         self.cq_shape = shape
         super().__init__(_to_occ(shape), name, color, show_faces, show_edges)
 
@@ -269,61 +333,75 @@ def _parent(cad_obj, obj_id):
         return []
 
 
-def _from_solidlist(cad_obj, obj_id, name="Solids", show_parent=True):
-    result = [Part(cad_obj, "%s_%d" % (name, obj_id))]
+def _from_solidlist(cad_obj, obj_id, name="Solids", color=None, alpha=None, show_parent=True):
+    color = get_color(color, get_default("default_color"), alpha)
+
+    result = [Part(cad_obj, "%s_%d" % (name, obj_id), color=color)]
     if show_parent:
         result = _parent(cad_obj, obj_id) + result
     return result
 
 
-def _from_facelist(cad_obj, obj_id, name="Faces", show_parent=True):
-    result = [Faces(cad_obj, "%s_%d" % (name, obj_id), color=Color(FACE_COLOR))]
+def _from_facelist(cad_obj, obj_id, name="Faces", color=None, alpha=None, show_parent=True):
+    color = get_color(color, FACE_COLOR, alpha)
+
+    result = [Faces(cad_obj, "%s_%d" % (name, obj_id), color=color)]
     if show_parent:
         result = _parent(cad_obj, obj_id) + result
     return result
 
 
 def _from_edgelist(cad_obj, obj_id, name="Edges", color=None, show_parent=True):
-    result = [Edges(cad_obj, "%s_%d" % (name, obj_id), color=Color(color or THICK_EDGE_COLOR), width=3)]
+    color = get_color(color, THICK_EDGE_COLOR, 1.0)
+
+    result = [Edges(cad_obj, "%s_%d" % (name, obj_id), color=color, width=3)]
     if show_parent:
         result = _parent(cad_obj, obj_id) + result
     return result
 
 
 def _from_wirelist(cad_obj, obj_id, name="Wires", color=None, show_parent=True):
-    result = [Edges(cad_obj, "%s_%d" % (name, obj_id), color=Color(color or THICK_EDGE_COLOR), width=3)]
+    color = get_color(color, THICK_EDGE_COLOR, 1.0)
+
+    result = [Edges(cad_obj, "%s_%d" % (name, obj_id), color=color, width=3)]
     if show_parent:
         result = _parent(cad_obj, obj_id) + result
     return result
 
 
-def _from_vector(vec, obj_id, name="Vector", show_parent=True):
+def _from_vector(vec, obj_id, name="Vector", color=None, show_parent=True):
+    color = get_color(color, THICK_EDGE_COLOR, 1.0)
+
     tmp = Workplane()
     obj = tmp.newObject([vec])
-    return _from_vectorlist(obj, obj_id, name, show_parent=show_parent)
+    return _from_vectorlist(obj, obj_id, name, color=color, show_parent=show_parent)
 
 
 def _from_vectorlist(cad_obj, obj_id, name="Vertices", color=None, show_parent=True):
+    color = get_color(color, VERTEX_COLOR, 1.0)
+
     if cad_obj.vals():
         vectors = cad_obj.vals()
     else:
         vectors = [cad_obj.val()]
     obj = cad_obj.newObject([Vertex.makeVertex(v.x, v.y, v.z) for v in vectors])
-    result = [Vertices(obj, "%s_%d" % (name, obj_id), color=Color(color or VERTEX_COLOR), size=6)]
+    result = [Vertices(obj, "%s_%d" % (name, obj_id), color=color, size=6)]
     if show_parent:
         result = _parent(cad_obj, obj_id) + result
     return result
 
 
 def _from_vertexlist(cad_obj, obj_id, name="Vertices", color=None, show_parent=True):
-    result = [Vertices(cad_obj, "%s_%d" % (name, obj_id), color=Color(color or VERTEX_COLOR), size=6)]
+    color = get_color(color, VERTEX_COLOR, 1.0)
+
+    result = [Vertices(cad_obj, "%s_%d" % (name, obj_id), color=color, size=6)]
     if show_parent:
         result = _parent(cad_obj, obj_id) + result
     return result
 
 
 # pylint:disable=protected-access
-def _from_sketch(cad_obj, obj_id, show_parent=True, show_selection=True):
+def _from_sketch(cad_obj, obj_id, color=None, alpha=None, show_parent=True, show_selection=True):
 
     result = []
 
@@ -344,20 +422,33 @@ def _from_sketch(cad_obj, obj_id, show_parent=True, show_selection=True):
             workplane.objects = [
                 Vertex.makeVertex(0, 0, 0).moved(loc * obj) for obj in cad_obj._selection for loc in locs
             ]
-            sel = _from_vertexlist(workplane, obj_id, name="Locations", show_parent=show_parent)
+            sel = _from_vertexlist(
+                workplane,
+                obj_id,
+                name="Locations",
+                color=color,
+                show_parent=show_parent,
+            )
 
         elif isinstance(cad_obj._selection[0], Face):
             for loc in locs:
                 workplane.objects += flatten([obj._faces.moved(loc).Faces() for obj in cad_obj._selection])
-            sel = _from_facelist(workplane, obj_id, name="Faces", show_parent=show_parent)
+            sel = _from_facelist(
+                workplane,
+                obj_id,
+                name="Faces",
+                color=color,
+                alpha=alpha,
+                show_parent=show_parent,
+            )
 
         elif isinstance(cad_obj._selection[0], (Edge, Wire)):
             workplane.objects = [edge.moved(loc) for edge in cad_obj._selection for loc in locs]
-            sel = _from_edgelist(workplane, obj_id, name="Edges", show_parent=show_parent)
+            sel = _from_edgelist(workplane, obj_id, name="Edges", color=color, show_parent=show_parent)
 
         elif isinstance(cad_obj._selection[0], Vertex):
             workplane.objects = [vertex.moved(loc) for vertex in cad_obj._selection for loc in locs]
-            sel = _from_vertexlist(workplane, obj_id, name="Vertices", show_parent=show_parent)
+            sel = _from_vertexlist(workplane, obj_id, name="Vertices", color=color, show_parent=show_parent)
 
         result.append(PartGroup(sel, name=f"Selection_{obj_id}"))
 
@@ -431,7 +522,12 @@ def from_assembly(cad_obj, top, loc=None, render_mates=False, mate_scale=1, defa
         rgb = (Color((255, 0, 0)), Color((0, 128, 0)), Color((0, 0, 255)))
         pg = PartGroup(
             [
-                Edges(to_edge(mate_def.mate, scale=mate_scale), name=name, width=3, color=rgb)
+                Edges(
+                    to_edge(mate_def.mate, scale=mate_scale),
+                    name=name,
+                    width=3,
+                    color=rgb,
+                )
                 for name, mate_def in top.mates.items()
                 if mate_def.assembly == cad_obj
             ],
@@ -445,8 +541,18 @@ def from_assembly(cad_obj, top, loc=None, render_mates=False, mate_scale=1, defa
     return PartGroup(parent + children, cad_obj.name, loc=render_loc)
 
 
-def _from_workplane(cad_obj, obj_id, name="Part", default_color=None, show_parent=False):
-    result = Part(cad_obj, "%s_%d" % (name, obj_id), color=Color(default_color))
+def _from_workplane(
+    cad_obj,
+    obj_id,
+    name="Part",
+    color=None,
+    alpha=None,
+    default_color=None,
+    show_parent=False,
+):
+    color = get_color(color, default_color, alpha)
+
+    result = Part(cad_obj, "%s_%d" % (name, obj_id), color=color)
     # if show_parent:
     #     result = _parent(cad_obj, obj_id) + result
     return result
@@ -498,43 +604,59 @@ def _debug(msg):
 
 
 def to_assembly(
-    *cad_objs, names=None, name="Group", render_mates=None, mate_scale=1, default_color=None, show_parent=True
+    *cad_objs,
+    names=None,
+    colors=None,
+    alphas=None,
+    name="Group",
+    render_mates=None,
+    mate_scale=1,
+    default_color=None,
+    show_parent=True,
 ):
     if names is None:
         names = [None] * len(cad_objs)
 
+    if colors is None:
+        colors = [None] * len(cad_objs)
+
+    if alphas is None:
+        alphas = [1.0] * len(cad_objs)
+
     default_color = get_default("default_color") if default_color is None else default_color
     assembly = PartGroup([], name)
     obj_id = 0
 
-    for obj_name, cad_obj in zip(names, cad_objs):
+    for obj_name, obj_color, obj_alpha, cad_obj in zip(names, colors, alphas, cad_objs):
 
         # Handle build123d objects and convert them to a format support by the following conversions
 
         if HAS_BUILD123D:
 
-            is_build123d = True
+            if hasattr(cad_obj, "_obj_name"):  # BuildPart, BuildSketch, BuildLine
+                _debug(f"CAD Obj {obj_id}: {type(cad_obj)}")
+                cad_obj = getattr(cad_obj, cad_obj._obj_name)
+                if not isinstance(cad_obj, bd.Compound):
+                    cad_obj = Shape.cast(cad_obj.wrapped)
 
-            if isinstance(cad_obj, bd.BuildPart):
-                _debug(f"CAD Obj {obj_id}: build123d.BuildPart")
-                cad_obj = cad_obj.part
-            elif isinstance(cad_obj, bd.BuildSketch):
-                _debug(f"CAD Obj {obj_id}: build123d.BuildSketch")
-                cad_obj = cad_obj.sketch
-            elif isinstance(cad_obj, bd.BuildLine):
-                _debug(f"CAD Obj {obj_id}: build123d.BuildLine")
-                cad_obj = cad_obj.line
-            elif isinstance(cad_obj, (bd.Compound, bd.ShapeList)):
-                _debug(f"CAD Obj {obj_id}: build123d.ShapeList")
-            else:
-                is_build123d = False
-
-            if is_build123d and isinstance(cad_obj, (bd.Compound, bd.ShapeList)):
+            elif isinstance(cad_obj, bd.ShapeList):
                 cad_obj = cq_wrap([Shape.cast(obj.wrapped) for obj in cad_obj])
 
-            if isinstance(cad_obj, bd.direct_api.Shape):
+            if isinstance(cad_obj, bd.Shape):
                 _debug(f"CAD Obj {obj_id}: build123d.Shape (Solid, Face, Wire, Edge, Vertex)")
-                cad_obj = Shape.cast(cad_obj.wrapped)
+                if isinstance(cad_obj, bd.Compound):
+                    t = type(list(cad_obj)[0])
+                    if all(isinstance(obj, t) for obj in cad_obj):
+                        cad_obj = cq_wrap([Shape.cast(obj.wrapped) for obj in cad_obj])
+                    else:
+                        cad_obj = Shape.cast(cad_obj.wrapped)
+                else:
+                    cad_obj = Shape.cast(cad_obj.wrapped)
+
+        if HAS_ALG123D:
+            if isinstance(cad_obj, (ad.MAssembly, ad.Mate)):
+                _debug(f"CAD Obj {obj_id}: alg123d MAssembly or Mate")
+                cad_obj = convert_alg123d_massembly(cad_obj)
 
         # Handle TopDS_Compound
 
@@ -575,13 +697,17 @@ def to_assembly(
             _debug(f"CAD Obj {obj_id}: MAssembly")
             assembly.add(
                 from_assembly(
-                    cad_obj, cad_obj, render_mates=render_mates, mate_scale=mate_scale, default_color=default_color
+                    cad_obj,
+                    cad_obj,
+                    render_mates=render_mates,
+                    mate_scale=mate_scale,
+                    default_color=default_color,
                 )
             )
 
         elif HAS_MASSEMBLY and isinstance(cad_obj, Mate):
             _debug(f"CAD Obj {obj_id}: Mate")
-            obj_name = "Mate" if obj_name is None else obj_name
+            obj_name = "Mate_%d" % obj_id if obj_name is None else obj_name
             assembly.add(_from_mate(cad_obj, name=obj_name, mate_scale=mate_scale))
 
         elif isinstance(cad_obj, CqAssembly):
@@ -594,95 +720,179 @@ def to_assembly(
                 _from_sketch(
                     cad_obj,
                     obj_id,
+                    obj_color,
+                    obj_alpha,
                     show_parent=show_parent,
                 )
             )
 
         elif isinstance(cad_obj, Face):
             _debug(f"CAD Obj {obj_id}: Face")
-            obj_name = "Edges" if obj_name is None else obj_name
-            assembly.add_list(_from_facelist(Workplane(cad_obj), obj_id, obj_name, show_parent=show_parent))
+            obj_name = "Faces" if obj_name is None else obj_name
+            assembly.add_list(
+                _from_facelist(
+                    Workplane(cad_obj),
+                    obj_id,
+                    obj_name,
+                    obj_color,
+                    obj_alpha,
+                    show_parent=show_parent,
+                )
+            )
 
         elif isinstance(cad_obj, Wire):
             _debug(f"CAD Obj {obj_id}: Wire")
             obj_name = "Wires" if obj_name is None else obj_name
-            assembly.add_list(_from_wirelist(Workplane(cad_obj), obj_id, obj_name, show_parent=show_parent))
+            assembly.add_list(
+                _from_wirelist(
+                    Workplane(cad_obj),
+                    obj_id,
+                    obj_name,
+                    obj_color,
+                    show_parent=show_parent,
+                )
+            )
 
         elif isinstance(cad_obj, Edge):
             _debug(f"CAD Obj {obj_id}: Edge")
-            obj_name = "Faces" if obj_name is None else obj_name
-            assembly.add_list(_from_edgelist(Workplane(cad_obj), obj_id, obj_name, show_parent=show_parent))
+            obj_name = "Edges" if obj_name is None else obj_name
+            assembly.add_list(
+                _from_edgelist(
+                    Workplane(cad_obj),
+                    obj_id,
+                    obj_name,
+                    obj_color,
+                    show_parent=show_parent,
+                )
+            )
 
         elif isinstance(cad_obj, Vertex):
             _debug(f"CAD Obj {obj_id}: Vertex")
             obj_name = "Vertices" if obj_name is None else obj_name
-            assembly.add_list(_from_vertexlist(Workplane(cad_obj), obj_id, obj_name, show_parent=show_parent))
+            assembly.add_list(
+                _from_vertexlist(
+                    Workplane(cad_obj),
+                    obj_id,
+                    obj_name,
+                    obj_color,
+                    show_parent=show_parent,
+                )
+            )
 
         elif _is_solidlist(cad_obj) and len(cad_obj.objects) > 1:
             _debug(f"CAD Obj {obj_id}: solidlist")
             obj_name = "Solids" if obj_name is None else obj_name
-            assembly.add_list(_from_solidlist(cad_obj, obj_id, obj_name, show_parent=show_parent))
+            assembly.add_list(
+                _from_solidlist(
+                    cad_obj,
+                    obj_id,
+                    obj_name,
+                    obj_color,
+                    obj_alpha,
+                    show_parent=show_parent,
+                )
+            )
 
         elif _is_facelist(cad_obj):
             _debug(f"CAD Obj {obj_id}: facelist")
             obj_name = "Faces" if obj_name is None else obj_name
-            assembly.add_list(_from_facelist(cad_obj, obj_id, obj_name, show_parent=show_parent))
+            assembly.add_list(
+                _from_facelist(
+                    cad_obj,
+                    obj_id,
+                    obj_name,
+                    obj_color,
+                    obj_alpha,
+                    show_parent=show_parent,
+                )
+            )
 
         elif _is_edgelist(cad_obj):
             _debug(f"CAD Obj {obj_id}: edgelist")
             obj_name = "Edges" if obj_name is None else obj_name
-            assembly.add_list(_from_edgelist(cad_obj, obj_id, obj_name, show_parent=show_parent))
+            assembly.add_list(_from_edgelist(cad_obj, obj_id, obj_name, obj_color, show_parent=show_parent))
 
         elif _is_wirelist(cad_obj):
             _debug(f"CAD Obj {obj_id}: wirelist")
             obj_name = "Wires" if obj_name is None else obj_name
-            assembly.add_list(_from_wirelist(cad_obj, obj_id, obj_name, show_parent=show_parent))
+            assembly.add_list(_from_wirelist(cad_obj, obj_id, obj_name, obj_color, show_parent=show_parent))
 
         elif _is_vertexlist(cad_obj):
             _debug(f"CAD Obj {obj_id}: vertexlist")
             obj_name = "Vertices" if obj_name is None else obj_name
-            assembly.add_list(_from_vertexlist(cad_obj, obj_id, obj_name, show_parent=show_parent))
+            assembly.add_list(_from_vertexlist(cad_obj, obj_id, obj_name, obj_color, show_parent=show_parent))
 
         elif isinstance(cad_obj, Vector):
             _debug(f"CAD Obj {obj_id}: Vector")
             obj_name = "Vector" if obj_name is None else obj_name
-            assembly.add_list(_from_vector(cad_obj, obj_id, obj_name, show_parent=show_parent))
+            assembly.add_list(_from_vector(cad_obj, obj_id, obj_name, obj_color, show_parent=show_parent))
 
         elif isinstance(cad_obj, Compound):
             _debug(f"CAD Obj {obj_id}: Compound")
-            obj_name = "Part" if obj_name is None else obj_name
-            if isinstance(list(cad_obj)[0], (Wire, Edge, Vertex)):
-                _debug(f"CAD Obj {obj_id}: Compound of wire, edge, vertex")
-                new_obj = Workplane()
-                new_obj.objects = [cad_obj]
-            else:
-                new_obj = cad_obj
-            assembly.add(
-                _from_workplane(
-                    Workplane(new_obj), obj_id, obj_name, default_color=default_color, show_parent=show_parent
-                )
-            )
+            obj_name = "Group" if obj_name is None else obj_name
+            show_parent = False
+            assembly2 = PartGroup([], name="%s_%s" % (obj_name, obj_id))
+            for i, obj in enumerate(cad_obj):
+                w = Workplane(obj)
+                if isinstance(obj, Vertex):
+                    assembly2.add_list(_from_vertexlist(w, i, "Vertices", obj_color, show_parent=show_parent))
+
+                elif isinstance(obj, Edge):
+                    assembly2.add_list(_from_edgelist(Workplane(obj), i, "Edges", obj_color, show_parent=show_parent))
+
+                elif isinstance(obj, Wire):
+                    assembly2.add_list(_from_wirelist(w, i, "Wires", obj_color, show_parent=show_parent))
+
+                elif isinstance(obj, Face):
+                    assembly2.add_list(_from_facelist(w, i, "Faces", obj_color, obj_alpha, show_parent=show_parent))
+
+                elif isinstance(obj, Solid):
+                    assembly2.add_list(_from_solidlist(w, i, "Solids", obj_color, obj_alpha, show_parent=show_parent))
+
+            assembly.add(assembly2)
 
         elif isinstance(cad_obj, Shape):
             _debug(f"CAD Obj {obj_id}: Shape")
             obj_name = "Part" if obj_name is None else obj_name
             assembly.add(
                 _from_workplane(
-                    Workplane(cad_obj), obj_id, obj_name, default_color=default_color, show_parent=show_parent
+                    Workplane(cad_obj),
+                    obj_id,
+                    obj_name,
+                    obj_color,
+                    obj_alpha,
+                    default_color=default_color,
+                    show_parent=show_parent,
                 )
             )
 
-        elif isinstance(cad_obj.val(), Vector):
+        elif hasattr(cad_obj, "val") and isinstance(cad_obj.val(), Vector):
             _debug(f"CAD Obj {obj_id}: Vector val()")
             obj_name = "Vector" if obj_name is None else obj_name
-            assembly.add_list(_from_vectorlist(cad_obj, obj_id, obj_name, show_parent=show_parent))
+            assembly.add_list(
+                _from_vectorlist(
+                    cad_obj,
+                    obj_id,
+                    obj_name,
+                    obj_color,
+                    show_parent=show_parent,
+                )
+            )
 
         elif isinstance(cad_obj, Workplane):
             _debug(f"CAD Obj {obj_id}: Workplane")
             obj_name = "Part" if obj_name is None else obj_name
             if len(cad_obj.vals()) == 1 and not isinstance(cad_obj.val(), Sketch):
                 assembly.add(
-                    _from_workplane(cad_obj, obj_id, obj_name, default_color=default_color, show_parent=show_parent)
+                    _from_workplane(
+                        cad_obj,
+                        obj_id,
+                        obj_name,
+                        obj_color,
+                        obj_alpha,
+                        default_color=default_color,
+                        show_parent=show_parent,
+                    )
                 )
             else:
                 assembly2 = PartGroup([], name="Group_%s" % obj_id)
@@ -693,7 +903,13 @@ def to_assembly(
                     else:
                         assembly2.add(
                             _from_workplane(
-                                Workplane(obj), j, obj_name, default_color=default_color, show_parent=show_parent
+                                Workplane(obj),
+                                j,
+                                obj_name,
+                                obj_color,
+                                obj_alpha,
+                                default_color=default_color,
+                                show_parent=show_parent,
                             )
                         )
                 assembly.add(assembly2)
@@ -705,7 +921,7 @@ def to_assembly(
     return assembly
 
 
-def show(*cad_objs, names=None, **kwargs):
+def show(*cad_objs, names=None, colors=None, alphas=None, **kwargs):
     """Show CAD objects in Jupyter
 
     Valid keywords:
@@ -789,6 +1005,8 @@ def show(*cad_objs, names=None, **kwargs):
         assembly = to_assembly(
             *cad_objs,
             names=names,
+            colors=colors,
+            alphas=alphas,
             render_mates=render_mates,
             mate_scale=mate_scale,
             default_color=default_color,
@@ -807,3 +1025,36 @@ def show(*cad_objs, names=None, **kwargs):
     else:
 
         return _show(None, **kwargs)
+
+
+def reset():
+    global OBJECTS
+
+    OBJECTS = {"objs": [], "names": [], "colors": [], "alphas": []}
+
+
+def show_object(obj, name=None, options=None, clear=False, **kwargs):
+    global OBJECTS
+
+    if clear:
+        reset()
+
+    if options is None:
+        color = None
+        alpha = 1.0
+    else:
+        color = options.get("color")
+        alpha = options.get("alpha", 1.0)
+
+    OBJECTS["objs"].append(obj)
+    OBJECTS["names"].append(name)
+    OBJECTS["colors"].append(color)
+    OBJECTS["alphas"].append(alpha)
+
+    show(
+        *OBJECTS["objs"],
+        names=OBJECTS["names"],
+        colors=OBJECTS["colors"],
+        alphas=OBJECTS["alphas"],
+        **kwargs,
+    )
