@@ -19,13 +19,13 @@ from jupyter_cadquery.cad_objects import to_assembly
 from jupyter_cadquery.base import _tessellate_group, get_normal_len, _combined_bb
 from jupyter_cadquery.defaults import get_default, get_defaults, preset
 
-
 import pickle
 import zmq
 
 ZMQ_PORT = 5555
 REQUEST_TIMEOUT = 2000
-OBJECTS = []
+
+OBJECTS = {"objs": [], "names": [], "colors": [], "alphas": []}
 
 
 def set_port(port):
@@ -80,16 +80,16 @@ class Progress:
         print(".", end="", flush=True)
 
 
-def _convert(*cad_objs, **kwargs):
-    color = kwargs.get("default_color")
-    if color is None:
-        color = get_default("default_color")
-
+def _convert(*cad_objs, names=None, colors=None, alphas=None, **kwargs):
     part_group = to_assembly(
         *cad_objs,
-        render_mates=kwargs.get("render_mates"),
+        names=names,
+        colors=colors,
+        alphas=alphas,
+        render_mates=kwargs.get("render_mates", False),
         mate_scale=kwargs.get("mate_scale", 1),
-        default_color=color,
+        default_color=kwargs.get("default_color", get_default("default_color")),
+        show_parent=kwargs.get("show_parent", get_default("show_parent")),
     )
 
     if len(part_group.objects) == 1 and isinstance(part_group.objects[0], PartGroup):
@@ -143,7 +143,7 @@ def animate(tracks, speed):
     send(data)
 
 
-def show(*cad_objs, **kwargs):
+def show(*cad_objs, names=None, colors=None, alphas=None, **kwargs):
     """Show CAD objects in Jupyter
 
     Valid keywords:
@@ -184,17 +184,32 @@ def show(*cad_objs, **kwargs):
     - quality            Use 'deviation'to control smoothness of rendered egdes
     """
 
-    data = _convert(*cad_objs, **kwargs)
+    data = _convert(*cad_objs, names=names, colors=colors, alphas=alphas, **kwargs)
     send(data)
 
 
-def show_object(obj, **kwargs):
-    global OBJECTS
-    OBJECTS.append(Part(obj, name=f"obj_{len(OBJECTS)}"))
-    show(PartGroup(OBJECTS), **kwargs)
-
-
 def reset():
     global OBJECTS
 
-    OBJECTS = []
+    OBJECTS = {"objs": [], "names": [], "colors": [], "alphas": []}
+
+
+def show_object(obj, name=None, options=None, clear=False, **kwargs):
+    global OBJECTS
+
+    if clear:
+        reset()
+
+    if options is None:
+        color = None
+        alpha = 1.0
+    else:
+        color = options.get("color")
+        alpha = options.get("alpha", 1.0)
+
+    OBJECTS["objs"].append(obj)
+    OBJECTS["names"].append(name)
+    OBJECTS["colors"].append(color)
+    OBJECTS["alphas"].append(alpha)
+
+    show(*OBJECTS["objs"], names=OBJECTS["names"], colors=OBJECTS["colors"], alphas=OBJECTS["alphas"], **kwargs)
